@@ -124,8 +124,8 @@ extern VALUE threads;
 extern VALUE next_thread;
 
 /* functions from context.c */
-extern void Init_context(VALUE mByebug);
-extern VALUE context_create(VALUE thread);
+extern void Init_byebug_context(VALUE mByebug);
+extern VALUE byebug_context_create(VALUE thread);
 extern VALUE context_dup(debug_context_t *context);
 extern void reset_stepping_stop_points(debug_context_t *context);
 extern VALUE call_with_debug_inspector(struct call_with_inspection_data *data);
