@@ -1,12 +1,15 @@
+# frozen_string_literal: true
+
 #
 # Main Container for all of Byebug's code
 #
 module Byebug
   #
-  # Enters byebug right before (or right after if _before_ is false) return
-  # events occur. Before entering byebug the init script is read.
+  # Starts byebug, and stops at the first line of user's code.
   #
   def self.attach
+    require "byebug/core"
+
     unless started?
       self.mode = :attached
 
@@ -14,7 +17,14 @@ module Byebug
       run_init_script
     end
 
-    current_context.step_out(2, true)
+    current_context.step_out(3, true)
+  end
+
+  def self.spawn(host = "localhost", port = nil)
+    require "byebug/core"
+
+    self.wait_connection = true
+    start_server(host, port || PORT)
   end
 end
 
@@ -28,5 +38,11 @@ module Kernel
     Byebug.attach
   end
 
-  alias_method :debugger, :byebug
+  def remote_byebug(host = "localhost", port = nil)
+    Byebug.spawn(host, port)
+
+    Byebug.attach
+  end
+
+  alias debugger byebug
 end
