@@ -1,4 +1,6 @@
-require 'byebug/helpers/toggle'
+# frozen_string_literal: true
+
+require "byebug/helpers/toggle"
 
 module Byebug
   #
@@ -8,30 +10,32 @@ module Byebug
     #
     # Disables all or specific breakpoints
     #
-    class BreakpointsSubcommand < Command
+    class BreakpointsCommand < Command
       include Helpers::ToggleHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* b(?:reakpoints)? (?:\s+ (.+))? \s*$/x
       end
 
-      def execute
-        enable_disable_breakpoints('disable', @match[1])
-      end
-
-      def short_description
-        'Disable all or specific breakpoints.'
-      end
-
-      def description
-        <<-EOD
+      def self.description
+        <<-DESCRIPTION
           dis[able] b[reakpoints][ <id1> <id2> .. <idn>]
 
           #{short_description}
 
           Give breakpoint numbers (separated by spaces) as arguments or no
           argument at all if you want to disable every breakpoint.
-        EOD
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Disable all or specific breakpoints."
+      end
+
+      def execute
+        enable_disable_breakpoints("disable", @match[1])
       end
     end
   end
