@@ -1,5 +1,7 @@
-require 'byebug/command'
-require 'byebug/helpers/parse'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "byebug/helpers/parse"
 
 module Byebug
   #
@@ -12,35 +14,44 @@ module Byebug
 
     self.allow_in_post_mortem = false
 
-    def regexp
+    def self.regexp
       /^\s* fin(?:ish)? (?:\s+(\S+))? \s*$/x
     end
 
+    def self.description
+      <<-DESCRIPTION
+        fin[ish][ n_frames]
+
+        #{short_description}
+
+        If no number is given, we run until the current frame returns. If a
+        number of frames `n_frames` is given, then we run until `n_frames`
+        return from the current position.
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Runs the program until frame returns"
+    end
+
     def execute
-      max_frames = @state.context.stack_size - @state.frame
       if @match[1]
-        n_frames, err = get_int(@match[1], 'finish', 0, max_frames - 1)
+        n_frames, err = get_int(@match[1], "finish", 0, max_frames - 1)
         return errmsg(err) unless n_frames
       else
         n_frames = 1
       end
 
-      force = n_frames == 0 ? true : false
-      @state.context.step_out(@state.frame + n_frames, force)
-      @state.frame = 0
-      @state.proceed
+      force = n_frames.zero? ? true : false
+      context.step_out(context.frame.pos + n_frames, force)
+      context.frame = 0
+      processor.proceed!
     end
 
-    def description
-      <<-EOD
-        fin[ish][ n_frames]
+    private
 
-        Execute until frame returns.
-
-        If no number is given, we run until the current frame returns. If a
-        number of frames `n_frames` is given, then we run until `n_frames`
-        return from the current position.
-      EOD
+    def max_frames
+      context.stack_size - context.frame.pos
     end
   end
 end
