@@ -1,9 +1,9 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
-require 'pathname'
-require 'byebug/command'
-require 'byebug/helpers/frame'
-require 'byebug/helpers/parse'
+require "pathname"
+require "byebug/command"
+require "byebug/helpers/frame"
+require "byebug/helpers/parse"
 
 module Byebug
   #
@@ -13,28 +13,20 @@ module Byebug
     include Helpers::FrameHelper
     include Helpers::ParseHelper
 
-    def regexp
+    self.allow_in_post_mortem = true
+
+    def self.regexp
       /^\s* f(?:rame)? (?:\s+(\S+))? \s*$/x
     end
 
-    def execute
-      unless @match[1]
-        print(pr('frame.line', get_pr_arguments(@state.frame)))
-        return
-      end
-
-      pos, err = get_int(@match[1], 'Frame')
-      return errmsg(err) unless pos
-
-      adjust_frame(pos, true)
-    end
-
-    def description
-      <<-EOD
+    def self.description
+      <<-DESCRIPTION
         f[rame][ frame-number]
 
-        Move the current frame to the specified frame number, or the 0 if no
-        frame-number has been given.
+        #{short_description}
+
+        If a frame number has been specified, to moves to that frame. Otherwise
+        it moves to the newest frame.
 
         A negative number indicates position from the other end, so "frame -1"
         moves to the oldest frame, and "frame 0" moves to the newest frame.
@@ -44,7 +36,22 @@ module Byebug
         if there is a front end also watching over things.
 
         Use the "bt" command to find out where you want to go.
-      EOD
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Moves to a frame in the call stack"
+    end
+
+    def execute
+      return print(pr("frame.line", context.frame.to_hash)) unless @match[1]
+
+      pos, err = get_int(@match[1], "Frame")
+      return errmsg(err) unless pos
+
+      switch_to_frame(pos)
+
+      ListCommand.new(processor).execute if Setting[:autolist]
     end
   end
 end
