@@ -1,4 +1,6 @@
-require 'byebug/helpers/file'
+# frozen_string_literal: true
+
+require "byebug/helpers/file"
 
 module Byebug
   #
@@ -19,27 +21,27 @@ module Byebug
       end
 
       def self.description
-        <<-EOD
+        <<-DESCRIPTION
           inf[o] f[ile]
 
           #{short_description}
 
           It informs about file name, number of lines, possible breakpoints in
           the file, last modification time and sha1 digest.
-        EOD
+        DESCRIPTION
       end
 
       def self.short_description
-        'Information about a particular source file.'
+        "Information about a particular source file."
       end
 
       def execute
         file = @match[1] || frame.file
         unless File.exist?(file)
-          return errmsg(pr('info.errors.undefined_file', file: file))
+          return errmsg(pr("info.errors.undefined_file", file: file))
         end
 
-        puts prettify <<-EOC
+        puts prettify <<-RUBY
           File #{info_file_basic(file)}
 
           Breakpoint line numbers: #{info_file_breakpoints(file)}
@@ -47,7 +49,7 @@ module Byebug
           Modification time: #{info_file_mtime(file)}
 
           Sha1 Signature: #{info_file_sha1(file)}
-        EOC
+        RUBY
       end
 
       private
@@ -56,7 +58,7 @@ module Byebug
         path = File.expand_path(file)
         return unless File.exist?(path)
 
-        s = n_lines(path) == 1 ? '' : 's'
+        s = n_lines(path) == 1 ? "" : "s"
         "#{path} (#{n_lines(path)} line#{s})"
       end
 
@@ -64,7 +66,7 @@ module Byebug
         breakpoints = Breakpoint.potential_lines(file)
         return unless breakpoints
 
-        breakpoints.to_a.sort.join(' ')
+        breakpoints.to_a.sort.join(" ")
       end
 
       def info_file_mtime(file)
@@ -72,7 +74,7 @@ module Byebug
       end
 
       def info_file_sha1(file)
-        require 'digest/sha1'
+        require "digest/sha1"
         Digest::SHA1.hexdigest(file)
       end
     end
