@@ -1,9 +1,11 @@
-require 'byebug/command'
-require 'byebug/helpers/bin'
-require 'byebug/helpers/path'
-require 'shellwords'
-require 'English'
-require 'rbconfig'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "byebug/helpers/bin"
+require "byebug/helpers/path"
+require "shellwords"
+require "English"
+require "rbconfig"
 
 module Byebug
   #
@@ -21,18 +23,18 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         restart [args]
 
         #{short_description}
 
         This is a re-exec - all byebug state is lost. If command arguments are
         passed those are used.
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Restarts the debugged program'
+      "Restarts the debugged program"
     end
 
     def execute
@@ -43,7 +45,7 @@ module Byebug
 
       cmd += (@match[:args] ? @match[:args].shellsplit : $ARGV)
 
-      puts pr('restart.success', cmd: cmd.shelljoin)
+      puts pr("restart.success", cmd: cmd.shelljoin)
       Kernel.exec(*cmd)
     end
 
@@ -55,7 +57,7 @@ module Byebug
     end
 
     def prepend_ruby_bin(cmd)
-      cmd.unshift(RbConfig.ruby) if which('ruby') != which(cmd.first)
+      cmd.unshift(RbConfig.ruby) if which("ruby") != which(cmd.first)
       cmd
     end
   end
