@@ -1,4 +1,6 @@
-require 'byebug/command'
+# frozen_string_literal: true
+
+require "byebug/command"
 
 module Byebug
   #
@@ -8,32 +10,33 @@ module Byebug
   #
   class SourceCommand < Command
     self.allow_in_control = true
+    self.allow_in_post_mortem = true
 
-    def regexp
+    def self.regexp
       /^\s* so(?:urce)? (?:\s+(\S+))? \s*$/x
     end
 
+    def self.description
+      <<-DESCRIPTION
+        source <file>
+
+        #{short_description}
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Restores a previously saved byebug session"
+    end
+
     def execute
       return puts(help) unless @match[1]
 
-      unless @state && @state.interface
-        return errmsg(pr('source.errors.not_available'))
-      end
-
       file = File.expand_path(@match[1]).strip
       unless File.exist?(file)
-        return errmsg(pr('source.errors.not_found', file: file))
+        return errmsg(pr("source.errors.not_found", file: file))
       end
 
-      @state.interface.read_file(file)
-    end
-
-    def description
-      <<-EOD
-        source <file>
-
-        Executes file <file> containing byebug commands.
-      EOD
+      processor.interface.read_file(file)
     end
   end
 end
