@@ -1,5 +1,7 @@
-require 'byebug/command'
-require 'byebug/helpers/parse'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "byebug/helpers/parse"
 
 module Byebug
   #
@@ -11,26 +13,28 @@ module Byebug
   class StepCommand < Command
     include Helpers::ParseHelper
 
-    self.allow_in_post_mortem = false
-
-    def regexp
+    def self.regexp
       /^\s* s(?:tep)? (?:\s+(\S+))? \s*$/x
     end
 
-    def execute
-      steps, err = parse_steps(@match[1], 'Steps')
-      return errmsg(err) unless steps
+    def self.description
+      <<-DESCRIPTION
+        s[tep][ times]
 
-      @state.context.step_into(steps, @state.frame)
-      @state.proceed
+        #{short_description}
+      DESCRIPTION
     end
 
-    def description
-      <<-EOD
-        s[tep][ nnn]
+    def self.short_description
+      "Steps into blocks or methods one or more times"
+    end
 
-        Steps (into methods) once or nnn times.
-      EOD
+    def execute
+      steps, err = parse_steps(@match[1], "Steps")
+      return errmsg(err) unless steps
+
+      context.step_into(steps, context.frame.pos)
+      processor.proceed!
     end
   end
 end
