@@ -1,4 +1,6 @@
-require 'byebug/helpers/thread'
+# frozen_string_literal: true
+
+require "byebug/helpers/thread"
 
 module Byebug
   #
@@ -8,27 +10,27 @@ module Byebug
     #
     # Information about the current thread
     #
-    class CurrentSubcommand < Command
+    class CurrentCommand < Command
       include Helpers::ThreadHelper
 
-      def regexp
+      def self.regexp
         /^\s* c(?:urrent)? \s*$/x
       end
 
-      def execute
-        display_context(@state.context)
-      end
-
-      def short_description
-        'Shows current thread information'
-      end
-
-      def description
-        <<-EOD
+      def self.description
+        <<-DESCRIPTION
           th[read] c[urrent]
 
           #{short_description}
-        EOD
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Shows current thread information"
+      end
+
+      def execute
+        display_context(context)
       end
     end
   end
