@@ -1,4 +1,6 @@
-require 'byebug/helpers/thread'
+# frozen_string_literal: true
+
+require "byebug/helpers/thread"
 
 module Byebug
   #
@@ -8,34 +10,34 @@ module Byebug
     #
     # Information about threads
     #
-    class ListSubcommand < Command
+    class ListCommand < Command
       include Helpers::ThreadHelper
 
-      def regexp
+      def self.regexp
         /^\s* l(?:ist)? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          th[read] l[ist] <thnum>
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Lists all threads"
+      end
+
       def execute
         contexts = Byebug.contexts.sort_by(&:thnum)
 
-        thread_list = prc('thread.context', contexts) do |context, _|
+        thread_list = prc("thread.context", contexts) do |context, _|
           thread_arguments(context)
         end
 
         print(thread_list)
       end
-
-      def short_description
-        'Lists all threads'
-      end
-
-      def description
-        <<-EOD
-          th[read] l[ist] <thnum>
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
