@@ -1,4 +1,6 @@
-require 'byebug/helpers/var'
+# frozen_string_literal: true
+
+require "byebug/helpers/var"
 
 module Byebug
   #
@@ -8,28 +10,30 @@ module Byebug
     #
     # Shows local variables in current scope
     #
-    class LocalSubcommand < Command
+    class LocalCommand < Command
       include Helpers::VarHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* l(?:ocal)? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          v[ar] l[ocal]
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Shows local variables in current scope."
+      end
+
       def execute
         var_local
       end
-
-      def short_description
-        'Shows local variables in current scope.'
-      end
-
-      def description
-        <<-EOD
-          v[ar] l[ocal]
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
