@@ -1,8 +1,8 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
-require 'pathname'
-require 'byebug/command'
-require 'byebug/helpers/frame'
+require "pathname"
+require "byebug/command"
+require "byebug/helpers/frame"
 
 module Byebug
   #
@@ -11,19 +11,17 @@ module Byebug
   class WhereCommand < Command
     include Helpers::FrameHelper
 
-    def regexp
+    self.allow_in_post_mortem = true
+
+    def self.regexp
       /^\s* (?:w(?:here)?|bt|backtrace) \s*$/x
     end
 
-    def execute
-      print_backtrace
-    end
-
-    def description
-      <<-EOD
+    def self.description
+      <<-DESCRIPTION
         w[here]|bt|backtrace
 
-        Display stack frames.
+        #{short_description}
 
         Print the entire stack frame. Each frame is numbered; the most recent
         frame is 0. A frame number can be referred to in the "frame" command.
@@ -31,14 +29,22 @@ module Byebug
         The position of the current frame is marked with -->. C-frames hang
         from their most immediate Ruby frame to indicate that they are not
         navigable.
-      EOD
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Displays the backtrace"
+    end
+
+    def execute
+      print_backtrace
     end
 
     private
 
     def print_backtrace
-      bt = prc('frame.line', (0...@state.context.stack_size)) do |_, index|
-        get_pr_arguments(index)
+      bt = prc("frame.line", (0...context.stack_size)) do |_, index|
+        Frame.new(context, index).to_hash
       end
 
       print(bt)
