@@ -1,4 +1,6 @@
-require 'byebug/helpers/eval'
+# frozen_string_literal: true
+
+require "byebug/helpers/eval"
 
 module Byebug
   module Helpers
@@ -13,7 +15,7 @@ module Byebug
           [name, safe_inspect(silent_eval(name.to_s, binding))]
         end
 
-        puts prv(vars, 'instance')
+        puts prv(vars, "instance")
       end
 
       def var_global
@@ -25,7 +27,7 @@ module Byebug
       end
 
       def var_instance(str)
-        obj = warning_eval(str || 'self')
+        obj = warning_eval(str || "self")
 
         var_list(obj.instance_variables, obj.instance_eval { binding })
       end
@@ -33,8 +35,8 @@ module Byebug
       def var_local
         locals = context.frame.locals
         cur_self = context.frame._self
-        locals[:self] = cur_self unless cur_self.to_s == 'main'
-        puts prv(locals.keys.sort.map { |k| [k, locals[k]] }, 'instance')
+        locals[:self] = cur_self unless cur_self.to_s == "main"
+        puts prv(locals.keys.sort.map { |k| [k, locals[k]] }, "instance")
       end
 
       def var_args
@@ -45,7 +47,7 @@ module Byebug
         arg_values = args.map { |arg| arg[1] }
 
         locals = all_locals.select { |k, _| arg_values.include?(k) }
-        puts prv(locals.keys.sort.map { |k| [k, locals[k]] }, 'instance')
+        puts prv(locals.keys.sort.map { |k| [k, locals[k]] }, "instance")
       end
     end
   end
