@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'yaml'
+require "yaml"
 
 module Byebug
   module Printers
@@ -11,17 +11,17 @@ module Byebug
       class MissedPath < StandardError; end
       class MissedArgument < StandardError; end
 
-      SEPARATOR = '.'.freeze
+      SEPARATOR = ".".freeze
 
       def type
-        self.class.name.split('::').last.downcase
+        self.class.name.split("::").last.downcase
       end
 
       private
 
       def locate(path)
         result = nil
-        contents.each do |_, contents|
+        contents.each_value do |contents|
           result = parts(path).reduce(contents) do |r, part|
             r && r.key?(part) ? r[part] : nil
           end
@@ -33,7 +33,7 @@ module Byebug
 
       def translate(string, args = {})
         # they may contain #{} string interpolation
-        string.gsub(/\|\w+$/, '').gsub(/([^#]?){([^}]*)}/) do
+        string.gsub(/\|\w+$/, "").gsub(/([^#]?){([^}]*)}/) do
           key = Regexp.last_match[2].to_s
           unless args.key?(key.to_sym)
             raise MissedArgument, "Missed argument #{key} for '#{string}'"
@@ -62,7 +62,7 @@ module Byebug
       end
 
       def contents_files
-        [File.join(__dir__, 'texts', 'base.yml')]
+        [File.join(__dir__, "texts", "base.yml")]
       end
     end
   end
