@@ -1,4 +1,6 @@
-require 'byebug/helpers/string'
+# frozen_string_literal: true
+
+require "byebug/helpers/string"
 
 module Byebug
   #
@@ -28,7 +30,7 @@ module Byebug
     end
 
     def to_sym
-      name = self.class.name.gsub(/^Byebug::/, '').gsub(/Setting$/, '')
+      name = self.class.name.gsub(/^Byebug::/, "").gsub(/Setting$/, "")
       name.gsub(/(.)([A-Z])/, '\1_\2').downcase.to_sym
     end
 
@@ -52,16 +54,23 @@ module Byebug
       def find(shortcut)
         abbr = shortcut =~ /^no/ ? shortcut[2..-1] : shortcut
         matches = settings.select do |key, value|
-          value.boolean? ? key =~ /#{abbr}/ : key =~ /#{shortcut}/
+          key =~ (value.boolean? ? /#{abbr}/ : /#{shortcut}/)
         end
         matches.size == 1 ? matches.values.first : nil
       end
 
+      #
+      # @todo DRY this up. Very similar code exists in the CommandList class
+      #
       def help_all
-        output = "  List of settings supported in byebug:\n  --\n"
+        output = "  List of supported settings:\n\n"
         width = settings.keys.max_by(&:size).size
-        settings.values.each do |sett|
-          output << format("  %-#{width}s -- %s\n", sett.to_sym, sett.banner)
+        settings.each_value do |sett|
+          output += format(
+            "  %<name>-#{width}s -- %<description>s\n",
+            name: sett.to_sym,
+            description: sett.banner
+          )
         end
         output + "\n"
       end
