@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
@@ -9,7 +11,7 @@ module Byebug
     DEFAULT = true
 
     def banner
-      'Automatically save command history record on exit'
+      "Automatically save command history record on exit"
     end
   end
 end
