@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
@@ -8,7 +10,7 @@ module Byebug
   #
   class BasenameSetting < Setting
     def banner
-      '<file>:<line> information after every stop uses short paths'
+      "<file>:<line> information after every stop uses short paths"
     end
   end
 end
