@@ -1,14 +1,16 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
   # Setting to customize the file where byebug's history is saved.
   #
   class HistfileSetting < Setting
-    DEFAULT = File.expand_path('.byebug_history')
+    DEFAULT = File.expand_path(".byebug_history")
 
     def banner
-      'File where cmd history is saved to. Default: ./.byebug_history'
+      "File where cmd history is saved to. Default: ./.byebug_history"
     end
 
     def to_s
