@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
@@ -9,7 +11,7 @@ module Byebug
     DEFAULT = 10
 
     def banner
-      'Set number of source lines to list by default'
+      "Set number of source lines to list by default"
     end
 
     def to_s
