@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
